@@ -7,8 +7,10 @@
 #' @param corpus Google corpus to search (see Details for possible values)
 #' @param year_start start year, default is 1500
 #' @param year_end end year, default is 2008
-#' @param tag apply a part-of-speech tag to the whole vector of phrases
 #' @param smoothing smoothing paramater, default is 3
+#' @param count logical, denoting whether phrase counts should be returned as
+#'   well as frequencies. Default is \code{FALSE}.
+#' @param tag apply a part-of-speech tag to the whole vector of phrases
 #' @details 
 #'  Google generated two datasets drawn from digitised books in the Google
 #'  Books collection. One was generated in July 2009, the second in July 2012.
@@ -64,7 +66,8 @@
 #' @export
 
 ngram <- function(phrases, corpus='eng_2012', year_start = 1500,
-                  year_end = 2008, smoothing = 3, tag = NULL) {
+                  year_end = 2008, smoothing = 3, count=FALSE,
+                  tag = NULL) {
   stopifnot(is.character(phrases))
   if (length(phrases) > 12){
     phrases <- phrases[1:12]
@@ -77,6 +80,10 @@ ngram <- function(phrases, corpus='eng_2012', year_start = 1500,
                                                     tag=tag))
   result <- do.call("rbind", dfs)
   result$Corpus <- as.factor(result$Corpus)
+  if (count) result <- add_count(result)
+  class(result) <- c("ngram", class(result))
+  attr(result, "smoothing") <- smoothing
+  attr(result, "case_sensitive") <- TRUE
   return(result)
 }
 
@@ -123,6 +130,12 @@ ngram_url <- function(phrases, query=character()){
 
 ngram_parse <- function(html){
   if (any(grepl("No valid ngrams to plot!<br>", html))) stop("No valid ngrams.") 
+  
+  # Warn about character substitution
+  lapply(grep("^Google has substituted ",
+              gsub("<.?b.?>","", sub("Replaced (.*) to match how we processed the books",
+                                              "Google has substituted \\1", html)),
+              value=TRUE), warning, call. = FALSE)
     
   cols <- lapply(strsplit(grep("addColumn", html, value=TRUE), ","), getElement, 2)
   
